@@ -272,7 +272,7 @@ GeomTextpath <- ggproto("GeomTextpath", Geom,
       text_smoothing = text_params$text_smoothing,
       default.units  = "npc",
       angle          = data$angle,
-      polar_params   = get_polar_params(coord),
+      polar_params   = get_polar_params(coord, panel_params),
       padding        = text_params$padding,
       rich           = text_params$rich,
       arrow          = arrow,
